@@ -6,11 +6,11 @@
 
 #include <assert.h>
 
-const char* FILE_NAME = "Sys/Socket/Ip_mreq_source.c";
+static const char* FILE_NAME = "Sys/Socket/Ip_mreq_source.c";
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__new(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef __OpenBSD__
-  env->die(env, stack, "The new method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+#if defined(__OpenBSD__)
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#new method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -28,8 +28,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__new(SPVM_ENV* env, SPVM_VALUE* stack)
 
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef __OpenBSD__
-  env->die(env, stack, "The DESTROY method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+#if defined(__OpenBSD__)
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#DESTROY method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_multi_request_source = stack[0].oval;
@@ -46,8 +46,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* st
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef __OpenBSD__
-  env->die(env, stack, "The imr_multiaddr method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+#if defined(__OpenBSD__)
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#imr_multiaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -71,8 +71,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_multiaddr(SPVM_ENV* env, SPVM_VAL
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef __OpenBSD__
-  env->die(env, stack, "The set_imr_multiaddr method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+#if defined(__OpenBSD__)
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_multiaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
@@ -89,8 +89,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef __OpenBSD__
-  env->die(env, stack, "The imr_interface method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+#if defined(__OpenBSD__)
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#imr_interface method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -114,8 +114,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VAL
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef __OpenBSD__
-  env->die(env, stack, "The set_imr_interface method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+#if defined(__OpenBSD__)
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_interface method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
@@ -132,8 +132,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_sourceaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef __OpenBSD__
-  env->die(env, stack, "The imr_sourceaddr method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+#if defined(__OpenBSD__)
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#imr_sourceaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -157,8 +157,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_sourceaddr(SPVM_ENV* env, SPVM_VA
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_sourceaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef __OpenBSD__
-  env->die(env, stack, "The set_imr_sourceaddr method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+#if defined(__OpenBSD__)
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_sourceaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
