@@ -5,21 +5,6 @@
 #include "spvm_socket_util.h"
 #include <assert.h>
 
-#if !defined(SPVM_SOCKET_UTIL_DEFINE_SOCKADDR_UN)
-  #if defined(_WIN32)
-  
-  #define UNIX_PATH_MAX 108
-  
-  struct sockaddr_un {
-    ADDRESS_FAMILY sun_family;
-    char sun_path[UNIX_PATH_MAX];
-  };
-  
-  #else
-    #include <sys/un.h>
-  #endif
-#endif
-
 static const char* FILE_NAME = "Sys/Socket/Sockaddr/Un.c";
 
 int32_t SPVM__Sys__Socket__Sockaddr__Un__new(SPVM_ENV* env, SPVM_VALUE* stack) {
@@ -96,7 +81,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__Un__set_sun_path(SPVM_ENV* env, SPVM_VALUE*
   void* obj_path = stack[1].oval;
   
   if (!obj_path) {
-    return env->die(env, stack, "The sun_path must be be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The path $sun_path must be be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* path = env->get_chars(env, stack, obj_path);
